# Table of Contents

- [filtering-in-custom-reports](<./filtering-in-custom-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Filtering in Custom Reports](<./Filtering-in-Custom-Reports.md>)
  - [Overview](<./Filtering-in-Custom-Reports/Overview.md>)
  - [Prerequisites](<./Filtering-in-Custom-Reports/Prerequisites.md>)
  - [Step 1: Navigate to the Project Directory](<./Filtering-in-Custom-Reports/Step-1-Navigate-to-the-Project-Directory.md>)
  - [Step 2: Create a Custom Report Module](<./Filtering-in-Custom-Reports/Step-2-Create-a-Custom-Report-Module.md>)
  - [Step 3: Import Facets into the Main Module](<./Filtering-in-Custom-Reports/Step-3-Import-Facets-into-the-Main-Module.md>)
  - [Step 4: Start the Development Server](<./Filtering-in-Custom-Reports/Step-4-Start-the-Development-Server.md>)
  - [Step 5: Use Filters in the Filter Sidebar](<./Filtering-in-Custom-Reports/Step-5-Use-Filters-in-the-Filter-Sidebar.md>)
  - [Summary](<./Filtering-in-Custom-Reports/Summary.md>)
